# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/matcher/v3/struct.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/matcher/v3/struct.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import value_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/type/matcher/v3/struct.proto\x12\x15\x65nvoy.type.matcher.v3\x1a!envoy/type/matcher/v3/value.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xac\x02\n\rStructMatcher\x12H\n\x04path\x18\x02 \x03(\x0b\x32\x30.envoy.type.matcher.v3.StructMatcher.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12<\n\x05value\x18\x03 \x01(\x0b\x32#.envoy.type.matcher.v3.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1aj\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:3\x9a\xc5\x88\x1e.\n,envoy.type.matcher.StructMatcher.PathSegmentB\x0e\n\x07segment\x12\x03\xf8\x42\x01:\'\x9a\xc5\x88\x1e\"\n envoy.type.matcher.StructMatcherB\x84\x01\n#io.envoyproxy.envoy.type.matcher.v3B\x0bStructProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.struct_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\013StructProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _globals['_STRUCTMATCHER_PATHSEGMENT'].oneofs_by_name['segment']._loaded_options = None
  _globals['_STRUCTMATCHER_PATHSEGMENT'].oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _globals['_STRUCTMATCHER_PATHSEGMENT'].fields_by_name['key']._loaded_options = None
  _globals['_STRUCTMATCHER_PATHSEGMENT'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_STRUCTMATCHER_PATHSEGMENT']._loaded_options = None
  _globals['_STRUCTMATCHER_PATHSEGMENT']._serialized_options = b'\232\305\210\036.\n,envoy.type.matcher.StructMatcher.PathSegment'
  _globals['_STRUCTMATCHER'].fields_by_name['path']._loaded_options = None
  _globals['_STRUCTMATCHER'].fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_STRUCTMATCHER'].fields_by_name['value']._loaded_options = None
  _globals['_STRUCTMATCHER'].fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STRUCTMATCHER']._loaded_options = None
  _globals['_STRUCTMATCHER']._serialized_options = b'\232\305\210\036\"\n envoy.type.matcher.StructMatcher'
  _globals['_STRUCTMATCHER']._serialized_start=188
  _globals['_STRUCTMATCHER']._serialized_end=488
  _globals['_STRUCTMATCHER_PATHSEGMENT']._serialized_start=341
  _globals['_STRUCTMATCHER_PATHSEGMENT']._serialized_end=447
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/route/route.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/route/route.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2

from envoy.api.v2.route.route_components_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/route/route.proto\x12\x12\x65nvoy.api.v2.route\x1a)envoy/api/v2/route/route_components.protoBk\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/routeP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.route.route_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/route'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/injected_credentials/generic/v3/generic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/extensions/injected_credentials/generic/v3/generic.proto\x12\x30\x65nvoy.extensions.injected_credentials.generic.v3\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x80\x01\n\x07Generic\x12X\n\ncredential\x18\x01 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1b\n\x06header\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x42\xc3\x01\n>io.envoyproxy.envoy.extensions.injected_credentials.generic.v3B\x0cGenericProtoP\x01Zagithub.com/envoyproxy/go-control-plane/envoy/extensions/injected_credentials/generic/v3;genericv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.injected_credentials.generic.v3.generic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.injected_credentials.generic.v3B\014GenericProtoP\001Zagithub.com/envoyproxy/go-control-plane/envoy/extensions/injected_credentials/generic/v3;genericv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _GENERIC.fields_by_name['credential']._options = None
  _GENERIC.fields_by_name['credential']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GENERIC.fields_by_name['header']._options = None
  _GENERIC.fields_by_name['header']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _globals['_GENERIC']._serialized_start=262
  _globals['_GENERIC']._serialized_end=390
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/matcher/metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/matcher/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import value_pb2 as envoy_dot_type_dot_matcher_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/type/matcher/metadata.proto\x12\x12\x65nvoy.type.matcher\x1a\x1e\x65nvoy/type/matcher/value.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe5\x01\n\x0fMetadataMatcher\x12\x17\n\x06\x66ilter\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12G\n\x04path\x18\x02 \x03(\x0b\x32/.envoy.type.matcher.MetadataMatcher.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x39\n\x05value\x18\x03 \x01(\x0b\x32 .envoy.type.matcher.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\x35\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\x0e\n\x07segment\x12\x03\xf8\x42\x01\x42v\n io.envoyproxy.envoy.type.matcherB\rMetadataProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\rMetadataProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _globals['_METADATAMATCHER_PATHSEGMENT'].oneofs_by_name['segment']._loaded_options = None
  _globals['_METADATAMATCHER_PATHSEGMENT'].oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _globals['_METADATAMATCHER_PATHSEGMENT'].fields_by_name['key']._loaded_options = None
  _globals['_METADATAMATCHER_PATHSEGMENT'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATAMATCHER'].fields_by_name['filter']._loaded_options = None
  _globals['_METADATAMATCHER'].fields_by_name['filter']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATAMATCHER'].fields_by_name['path']._loaded_options = None
  _globals['_METADATAMATCHER'].fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_METADATAMATCHER'].fields_by_name['value']._loaded_options = None
  _globals['_METADATAMATCHER'].fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_METADATAMATCHER']._serialized_start=146
  _globals['_METADATAMATCHER']._serialized_end=375
  _globals['_METADATAMATCHER_PATHSEGMENT']._serialized_start=322
  _globals['_METADATAMATCHER_PATHSEGMENT']._serialized_end=375
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/common/key_value/v3/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/common/key_value/v3/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/config/common/key_value/v3/config.proto\x12 envoy.config.common.key_value.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"e\n\x13KeyValueStoreConfig\x12\x44\n\x06\x63onfig\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x42\x9c\x01\n.io.envoyproxy.envoy.config.common.key_value.v3B\x0b\x43onfigProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/config/common/key_value/v3;key_valuev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.common.key_value.v3.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.io.envoyproxy.envoy.config.common.key_value.v3B\013ConfigProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/config/common/key_value/v3;key_valuev3\272\200\310\321\006\002\020\002'
  _globals['_KEYVALUESTORECONFIG'].fields_by_name['config']._loaded_options = None
  _globals['_KEYVALUESTORECONFIG'].fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_KEYVALUESTORECONFIG']._loaded_options = None
  _globals['_KEYVALUESTORECONFIG']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_KEYVALUESTORECONFIG']._serialized_start=210
  _globals['_KEYVALUESTORECONFIG']._serialized_end=311
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/grpc_field_extraction/v3/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/grpc_field_extraction/v3/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/filters/http/grpc_field_extraction/v3/config.proto\x12\x36\x65nvoy.extensions.filters.http.grpc_field_extraction.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf2\x02\n\x19GrpcFieldExtractionConfig\x12\x42\n\x0e\x64\x65scriptor_set\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x89\x01\n\x15\x65xtractions_by_method\x18\x02 \x03(\x0b\x32j.envoy.extensions.filters.http.grpc_field_extraction.v3.GrpcFieldExtractionConfig.ExtractionsByMethodEntry\x1a\x84\x01\n\x18\x45xtractionsByMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12W\n\x05value\x18\x02 \x01(\x0b\x32H.envoy.extensions.filters.http.grpc_field_extraction.v3.FieldExtractions:\x02\x38\x01\"\xb4\x02\n\x10\x46ieldExtractions\x12\x88\x01\n\x19request_field_extractions\x18\x01 \x03(\x0b\x32\x65.envoy.extensions.filters.http.grpc_field_extraction.v3.FieldExtractions.RequestFieldExtractionsEntry\x1a\x94\x01\n\x1cRequestFieldExtractionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x63\n\x05value\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.http.grpc_field_extraction.v3.RequestFieldValueDisposition:\x02\x38\x01\"I\n\x1cRequestFieldValueDisposition\x12\x1a\n\x10\x64ynamic_metadata\x18\x01 \x01(\tH\x00\x42\r\n\x0b\x64ispositionB\xd4\x01\nDio.envoyproxy.envoy.extensions.filters.http.grpc_field_extraction.v3B\x0b\x43onfigProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_field_extraction/v3;grpc_field_extractionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_field_extraction.v3.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nDio.envoyproxy.envoy.extensions.filters.http.grpc_field_extraction.v3B\013ConfigProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_field_extraction/v3;grpc_field_extractionv3\272\200\310\321\006\002\020\002'
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._loaded_options = None
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._serialized_options = b'8\001'
  _globals['_GRPCFIELDEXTRACTIONCONFIG'].fields_by_name['descriptor_set']._loaded_options = None
  _globals['_GRPCFIELDEXTRACTIONCONFIG'].fields_by_name['descriptor_set']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._loaded_options = None
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GRPCFIELDEXTRACTIONCONFIG']._serialized_start=217
  _globals['_GRPCFIELDEXTRACTIONCONFIG']._serialized_end=587
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._serialized_start=455
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._serialized_end=587
  _globals['_FIELDEXTRACTIONS']._serialized_start=590
  _globals['_FIELDEXTRACTIONS']._serialized_end=898
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._serialized_start=750
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._serialized_end=898
  _globals['_REQUESTFIELDVALUEDISPOSITION']._serialized_start=900
  _globals['_REQUESTFIELDVALUEDISPOSITION']._serialized_end=973
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/on_demand/v3/on_demand.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/on_demand/v3/on_demand.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/on_demand/v3/on_demand.proto\x12*envoy.extensions.filters.http.on_demand.v3\x1a(envoy/config/core/v3/config_source.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x92\x01\n\x0bOnDemandCds\x12<\n\x06source\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11resources_locator\x18\x02 \x01(\t\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x89\x01\n\x08OnDemand\x12\x46\n\x05odcds\x18\x01 \x01(\x0b\x32\x37.envoy.extensions.filters.http.on_demand.v3.OnDemandCds:5\x9a\xc5\x88\x1e\x30\n.envoy.config.filter.http.on_demand.v2.OnDemand\"X\n\x0ePerRouteConfig\x12\x46\n\x05odcds\x18\x01 \x01(\x0b\x32\x37.envoy.extensions.filters.http.on_demand.v3.OnDemandCdsB\xb2\x01\n8io.envoyproxy.envoy.extensions.filters.http.on_demand.v3B\rOnDemandProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/on_demand/v3;on_demandv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.on_demand.v3.on_demand_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.on_demand.v3B\rOnDemandProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/on_demand/v3;on_demandv3\272\200\310\321\006\002\020\002'
  _globals['_ONDEMANDCDS'].fields_by_name['source']._loaded_options = None
  _globals['_ONDEMANDCDS'].fields_by_name['source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_ONDEMAND']._loaded_options = None
  _globals['_ONDEMAND']._serialized_options = b'\232\305\210\0360\n.envoy.config.filter.http.on_demand.v2.OnDemand'
  _globals['_ONDEMANDCDS']._serialized_start=272
  _globals['_ONDEMANDCDS']._serialized_end=418
  _globals['_ONDEMAND']._serialized_start=421
  _globals['_ONDEMAND']._serialized_end=558
  _globals['_PERROUTECONFIG']._serialized_start=560
  _globals['_PERROUTECONFIG']._serialized_end=648
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/http/grpc_stats/v2alpha/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/http/grpc_stats/v2alpha/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_method_list_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/config/filter/http/grpc_stats/v2alpha/config.proto\x12+envoy.config.filter.http.grpc_stats.v2alpha\x1a(envoy/api/v2/core/grpc_method_list.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xd3\x01\n\x0c\x46ilterConfig\x12\x19\n\x11\x65mit_filter_state\x18\x01 \x01(\x08\x12N\n!individual_method_stats_allowlist\x18\x02 \x01(\x0b\x32!.envoy.api.v2.core.GrpcMethodListH\x00\x12;\n\x15stats_for_all_methods\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x42\x1b\n\x19per_method_stat_specifier\"M\n\x0c\x46ilterObject\x12\x1d\n\x15request_message_count\x18\x01 \x01(\x04\x12\x1e\n\x16response_message_count\x18\x02 \x01(\x04\x42\xd9\x01\n9io.envoyproxy.envoy.config.filter.http.grpc_stats.v2alphaB\x0b\x43onfigProtoP\x01ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/grpc_stats/v2alpha\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.grpc_stats.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.grpc_stats.v2alpha.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9io.envoyproxy.envoy.config.filter.http.grpc_stats.v2alphaB\013ConfigProtoP\001ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/grpc_stats/v2alpha\362\230\376\217\005-\022+envoy.extensions.filters.http.grpc_stats.v3\272\200\310\321\006\002\020\001'
  _globals['_FILTERCONFIG']._serialized_start=243
  _globals['_FILTERCONFIG']._serialized_end=454
  _globals['_FILTEROBJECT']._serialized_start=456
  _globals['_FILTEROBJECT']._serialized_end=533
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/routing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/routing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18google/api/routing.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"G\n\x0bRoutingRule\x12\x38\n\x12routing_parameters\x18\x02 \x03(\x0b\x32\x1c.google.api.RoutingParameter\"8\n\x10RoutingParameter\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x15\n\rpath_template\x18\x02 \x01(\t:K\n\x07routing\x12\x1e.google.protobuf.MethodOptions\x18\xb1\xca\xbc\" \x01(\x0b\x32\x17.google.api.RoutingRuleBj\n\x0e\x63om.google.apiB\x0cRoutingProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.routing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\014RoutingProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\242\002\004GAPI'
  _globals['_ROUTINGRULE']._serialized_start=74
  _globals['_ROUTINGRULE']._serialized_end=145
  _globals['_ROUTINGPARAMETER']._serialized_start=147
  _globals['_ROUTINGPARAMETER']._serialized_end=203
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/fraction.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/fraction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agoogle/type/fraction.proto\x12\x0bgoogle.type\"2\n\x08\x46raction\x12\x11\n\tnumerator\x18\x01 \x01(\x03\x12\x13\n\x0b\x64\x65nominator\x18\x02 \x01(\x03\x42\x66\n\x0f\x63om.google.typeB\rFractionProtoP\x01Z<google.golang.org/genproto/googleapis/type/fraction;fraction\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.fraction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\rFractionProtoP\001Z<google.golang.org/genproto/googleapis/type/fraction;fraction\242\002\003GTP'
  _globals['_FRACTION']._serialized_start=43
  _globals['_FRACTION']._serialized_end=93
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/stat_sinks/open_telemetry/v3/open_telemetry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/stat_sinks/open_telemetry/v3/open_telemetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBenvoy/extensions/stat_sinks/open_telemetry/v3/open_telemetry.proto\x12-envoy.extensions.stat_sinks.open_telemetry.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x02\n\nSinkConfig\x12\x43\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12!\n\x19report_counters_as_deltas\x18\x02 \x01(\x08\x12#\n\x1breport_histograms_as_deltas\x18\x03 \x01(\x08\x12;\n\x17\x65mit_tags_as_attributes\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x16use_tag_extracted_name\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0e\n\x06prefix\x18\x06 \x01(\tB\x19\n\x12protocol_specifier\x12\x03\xf8\x42\x01\x42\xc2\x01\n;io.envoyproxy.envoy.extensions.stat_sinks.open_telemetry.v3B\x12OpenTelemetryProtoP\x01Zegithub.com/envoyproxy/go-control-plane/envoy/extensions/stat_sinks/open_telemetry/v3;open_telemetryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.stat_sinks.open_telemetry.v3.open_telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n;io.envoyproxy.envoy.extensions.stat_sinks.open_telemetry.v3B\022OpenTelemetryProtoP\001Zegithub.com/envoyproxy/go-control-plane/envoy/extensions/stat_sinks/open_telemetry/v3;open_telemetryv3\272\200\310\321\006\002\020\002'
  _globals['_SINKCONFIG'].oneofs_by_name['protocol_specifier']._loaded_options = None
  _globals['_SINKCONFIG'].oneofs_by_name['protocol_specifier']._serialized_options = b'\370B\001'
  _globals['_SINKCONFIG'].fields_by_name['grpc_service']._loaded_options = None
  _globals['_SINKCONFIG'].fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_SINKCONFIG']._serialized_start=247
  _globals['_SINKCONFIG']._serialized_end=564
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/matcher/path.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/matcher/path.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65nvoy/type/matcher/path.proto\x12\x12\x65nvoy.type.matcher\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"W\n\x0bPathMatcher\x12;\n\x04path\x18\x01 \x01(\x0b\x32!.envoy.type.matcher.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x0b\n\x04rule\x12\x03\xf8\x42\x01\x42r\n io.envoyproxy.envoy.type.matcherB\tPathProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.path_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\tPathProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _globals['_PATHMATCHER'].oneofs_by_name['rule']._loaded_options = None
  _globals['_PATHMATCHER'].oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _globals['_PATHMATCHER'].fields_by_name['path']._loaded_options = None
  _globals['_PATHMATCHER'].fields_by_name['path']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_PATHMATCHER']._serialized_start=142
  _globals['_PATHMATCHER']._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/health_checkers/redis/v3/redis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/health_checkers/redis/v3/redis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5envoy/extensions/health_checkers/redis/v3/redis.proto\x12)envoy.extensions.health_checkers.redis.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"G\n\x05Redis\x12\x0b\n\x03key\x18\x01 \x01(\t:1\x9a\xc5\x88\x1e,\n*envoy.config.health_checker.redis.v2.RedisB\xa9\x01\n7io.envoyproxy.envoy.extensions.health_checkers.redis.v3B\nRedisProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/extensions/health_checkers/redis/v3;redisv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.health_checkers.redis.v3.redis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.envoyproxy.envoy.extensions.health_checkers.redis.v3B\nRedisProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/extensions/health_checkers/redis/v3;redisv3\272\200\310\321\006\002\020\002'
  _globals['_REDIS']._loaded_options = None
  _globals['_REDIS']._serialized_options = b'\232\305\210\036,\n*envoy.config.health_checker.redis.v2.Redis'
  _globals['_REDIS']._serialized_start=166
  _globals['_REDIS']._serialized_end=237
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/opentelemetry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/opentelemetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.config.core.v3 import http_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__service__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/trace/v3/opentelemetry.proto\x12\x15\x65nvoy.config.trace.v3\x1a$envoy/config/core/v3/extension.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\'envoy/config/core/v3/http_service.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xd0\x02\n\x13OpenTelemetryConfig\x12N\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x15\xf2\x98\xfe\x8f\x05\x0f\x12\rotlp_exporter\x12N\n\x0chttp_service\x18\x03 \x01(\x0b\x32!.envoy.config.core.v3.HttpServiceB\x15\xf2\x98\xfe\x8f\x05\x0f\x12\rotlp_exporter\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x46\n\x12resource_detectors\x18\x04 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12;\n\x07sampler\x18\x05 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x89\x01\n#io.envoyproxy.envoy.config.trace.v3B\x12OpentelemetryProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.opentelemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\022OpentelemetryProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\272\200\310\321\006\002\020\002'
  _globals['_OPENTELEMETRYCONFIG'].fields_by_name['grpc_service']._loaded_options = None
  _globals['_OPENTELEMETRYCONFIG'].fields_by_name['grpc_service']._serialized_options = b'\362\230\376\217\005\017\022\rotlp_exporter'
  _globals['_OPENTELEMETRYCONFIG'].fields_by_name['http_service']._loaded_options = None
  _globals['_OPENTELEMETRYCONFIG'].fields_by_name['http_service']._serialized_options = b'\362\230\376\217\005\017\022\rotlp_exporter'
  _globals['_OPENTELEMETRYCONFIG']._serialized_start=252
  _globals['_OPENTELEMETRYCONFIG']._serialized_end=588
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: opentelemetry/proto/trace/v1/trace_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'opentelemetry/proto/trace/v1/trace_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/opentelemetry/proto/trace/v1/trace_config.proto\x12\x1copentelemetry.proto.trace.v1\"\xc8\x03\n\x0bTraceConfig\x12I\n\x10\x63onstant_sampler\x18\x01 \x01(\x0b\x32-.opentelemetry.proto.trace.v1.ConstantSamplerH\x00\x12O\n\x14trace_id_ratio_based\x18\x02 \x01(\x0b\x32/.opentelemetry.proto.trace.v1.TraceIdRatioBasedH\x00\x12R\n\x15rate_limiting_sampler\x18\x03 \x01(\x0b\x32\x31.opentelemetry.proto.trace.v1.RateLimitingSamplerH\x00\x12 \n\x18max_number_of_attributes\x18\x04 \x01(\x03\x12\"\n\x1amax_number_of_timed_events\x18\x05 \x01(\x03\x12\x30\n(max_number_of_attributes_per_timed_event\x18\x06 \x01(\x03\x12\x1b\n\x13max_number_of_links\x18\x07 \x01(\x03\x12)\n!max_number_of_attributes_per_link\x18\x08 \x01(\x03\x42\t\n\x07sampler\"\xa9\x01\n\x0f\x43onstantSampler\x12P\n\x08\x64\x65\x63ision\x18\x01 \x01(\x0e\x32>.opentelemetry.proto.trace.v1.ConstantSampler.ConstantDecision\"D\n\x10\x43onstantDecision\x12\x0e\n\nALWAYS_OFF\x10\x00\x12\r\n\tALWAYS_ON\x10\x01\x12\x11\n\rALWAYS_PARENT\x10\x02\"*\n\x11TraceIdRatioBased\x12\x15\n\rsamplingRatio\x18\x01 \x01(\x01\"\"\n\x13RateLimitingSampler\x12\x0b\n\x03qps\x18\x01 \x01(\x03\x42~\n\x1fio.opentelemetry.proto.trace.v1B\x10TraceConfigProtoP\x01ZGgithub.com/open-telemetry/opentelemetry-proto/gen/go/collector/trace/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.trace.v1.trace_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.opentelemetry.proto.trace.v1B\020TraceConfigProtoP\001ZGgithub.com/open-telemetry/opentelemetry-proto/gen/go/collector/trace/v1'
  _globals['_TRACECONFIG']._serialized_start=82
  _globals['_TRACECONFIG']._serialized_end=538
  _globals['_CONSTANTSAMPLER']._serialized_start=541
  _globals['_CONSTANTSAMPLER']._serialized_end=710
  _globals['_CONSTANTSAMPLER_CONSTANTDECISION']._serialized_start=642
  _globals['_CONSTANTSAMPLER_CONSTANTDECISION']._serialized_end=710
  _globals['_TRACEIDRATIOBASED']._serialized_start=712
  _globals['_TRACEIDRATIOBASED']._serialized_end=754
  _globals['_RATELIMITINGSAMPLER']._serialized_start=756
  _globals['_RATELIMITINGSAMPLER']._serialized_end=790
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto\x12)envoy.extensions.filters.http.ext_proc.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcc\x06\n\x0eProcessingMode\x12o\n\x13request_header_mode\x18\x01 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x14response_header_mode\x18\x02 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12k\n\x11request_body_mode\x18\x03 \x01(\x0e\x32\x46.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12l\n\x12response_body_mode\x18\x04 \x01(\x0e\x32\x46.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x14request_trailer_mode\x18\x05 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x15response_trailer_mode\x18\x06 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"1\n\x0eHeaderSendMode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04SEND\x10\x01\x12\x08\n\x04SKIP\x10\x02\"d\n\x0c\x42odySendMode\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08STREAMED\x10\x01\x12\x0c\n\x08\x42UFFERED\x10\x02\x12\x14\n\x10\x42UFFERED_PARTIAL\x10\x03\x12\x18\n\x14\x46ULL_DUPLEX_STREAMED\x10\x04\x42\xb5\x01\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\x13ProcessingModeProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ext_proc.v3.processing_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\023ProcessingModeProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\272\200\310\321\006\002\020\002'
  _globals['_PROCESSINGMODE'].fields_by_name['request_header_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['request_header_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['response_header_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['response_header_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['request_body_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['request_body_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['response_body_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['response_body_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['request_trailer_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['request_trailer_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['response_trailer_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['response_trailer_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE']._serialized_start=167
  _globals['_PROCESSINGMODE']._serialized_end=1011
  _globals['_PROCESSINGMODE_HEADERSENDMODE']._serialized_start=860
  _globals['_PROCESSINGMODE_HEADERSENDMODE']._serialized_end=909
  _globals['_PROCESSINGMODE_BODYSENDMODE']._serialized_start=911
  _globals['_PROCESSINGMODE_BODYSENDMODE']._serialized_end=1011
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: validate/validate.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'validate/validate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17validate/validate.proto\x12\x08validate\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x98\x07\n\nFieldRules\x12\'\n\x07message\x18\x11 \x01(\x0b\x32\x16.validate.MessageRules\x12%\n\x05\x66loat\x18\x01 \x01(\x0b\x32\x14.validate.FloatRulesH\x00\x12\'\n\x06\x64ouble\x18\x02 \x01(\x0b\x32\x15.validate.DoubleRulesH\x00\x12%\n\x05int32\x18\x03 \x01(\x0b\x32\x14.validate.Int32RulesH\x00\x12%\n\x05int64\x18\x04 \x01(\x0b\x32\x14.validate.Int64RulesH\x00\x12\'\n\x06uint32\x18\x05 \x01(\x0b\x32\x15.validate.UInt32RulesH\x00\x12\'\n\x06uint64\x18\x06 \x01(\x0b\x32\x15.validate.UInt64RulesH\x00\x12\'\n\x06sint32\x18\x07 \x01(\x0b\x32\x15.validate.SInt32RulesH\x00\x12\'\n\x06sint64\x18\x08 \x01(\x0b\x32\x15.validate.SInt64RulesH\x00\x12)\n\x07\x66ixed32\x18\t \x01(\x0b\x32\x16.validate.Fixed32RulesH\x00\x12)\n\x07\x66ixed64\x18\n \x01(\x0b\x32\x16.validate.Fixed64RulesH\x00\x12+\n\x08sfixed32\x18\x0b \x01(\x0b\x32\x17.validate.SFixed32RulesH\x00\x12+\n\x08sfixed64\x18\x0c \x01(\x0b\x32\x17.validate.SFixed64RulesH\x00\x12#\n\x04\x62ool\x18\r \x01(\x0b\x32\x13.validate.BoolRulesH\x00\x12\'\n\x06string\x18\x0e \x01(\x0b\x32\x15.validate.StringRulesH\x00\x12%\n\x05\x62ytes\x18\x0f \x01(\x0b\x32\x14.validate.BytesRulesH\x00\x12#\n\x04\x65num\x18\x10 \x01(\x0b\x32\x13.validate.EnumRulesH\x00\x12+\n\x08repeated\x18\x12 \x01(\x0b\x32\x17.validate.RepeatedRulesH\x00\x12!\n\x03map\x18\x13 \x01(\x0b\x32\x12.validate.MapRulesH\x00\x12!\n\x03\x61ny\x18\x14 \x01(\x0b\x32\x12.validate.AnyRulesH\x00\x12+\n\x08\x64uration\x18\x15 \x01(\x0b\x32\x17.validate.DurationRulesH\x00\x12-\n\ttimestamp\x18\x16 \x01(\x0b\x32\x18.validate.TimestampRulesH\x00\x42\x06\n\x04type\"\x7f\n\nFloatRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x02\x12\n\n\x02lt\x18\x02 \x01(\x02\x12\x0b\n\x03lte\x18\x03 \x01(\x02\x12\n\n\x02gt\x18\x04 \x01(\x02\x12\x0b\n\x03gte\x18\x05 \x01(\x02\x12\n\n\x02in\x18\x06 \x03(\x02\x12\x0e\n\x06not_in\x18\x07 \x03(\x02\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x80\x01\n\x0b\x44oubleRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x01\x12\n\n\x02lt\x18\x02 \x01(\x01\x12\x0b\n\x03lte\x18\x03 \x01(\x01\x12\n\n\x02gt\x18\x04 \x01(\x01\x12\x0b\n\x03gte\x18\x05 \x01(\x01\x12\n\n\x02in\x18\x06 \x03(\x01\x12\x0e\n\x06not_in\x18\x07 \x03(\x01\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x7f\n\nInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x05\x12\n\n\x02lt\x18\x02 \x01(\x05\x12\x0b\n\x03lte\x18\x03 \x01(\x05\x12\n\n\x02gt\x18\x04 \x01(\x05\x12\x0b\n\x03gte\x18\x05 \x01(\x05\x12\n\n\x02in\x18\x06 \x03(\x05\x12\x0e\n\x06not_in\x18\x07 \x03(\x05\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x7f\n\nInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x03\x12\n\n\x02lt\x18\x02 \x01(\x03\x12\x0b\n\x03lte\x18\x03 \x01(\x03\x12\n\n\x02gt\x18\x04 \x01(\x03\x12\x0b\n\x03gte\x18\x05 \x01(\x03\x12\n\n\x02in\x18\x06 \x03(\x03\x12\x0e\n\x06not_in\x18\x07 \x03(\x03\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x80\x01\n\x0bUInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\r\x12\n\n\x02lt\x18\x02 \x01(\r\x12\x0b\n\x03lte\x18\x03 \x01(\r\x12\n\n\x02gt\x18\x04 \x01(\r\x12\x0b\n\x03gte\x18\x05 \x01(\r\x12\n\n\x02in\x18\x06 \x03(\r\x12\x0e\n\x06not_in\x18\x07 \x03(\r\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x80\x01\n\x0bUInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x04\x12\n\n\x02lt\x18\x02 \x01(\x04\x12\x0b\n\x03lte\x18\x03 \x01(\x04\x12\n\n\x02gt\x18\x04 \x01(\x04\x12\x0b\n\x03gte\x18\x05 \x01(\x04\x12\n\n\x02in\x18\x06 \x03(\x04\x12\x0e\n\x06not_in\x18\x07 \x03(\x04\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x80\x01\n\x0bSInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x11\x12\n\n\x02lt\x18\x02 \x01(\x11\x12\x0b\n\x03lte\x18\x03 \x01(\x11\x12\n\n\x02gt\x18\x04 \x01(\x11\x12\x0b\n\x03gte\x18\x05 \x01(\x11\x12\n\n\x02in\x18\x06 \x03(\x11\x12\x0e\n\x06not_in\x18\x07 \x03(\x11\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x80\x01\n\x0bSInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x12\x12\n\n\x02lt\x18\x02 \x01(\x12\x12\x0b\n\x03lte\x18\x03 \x01(\x12\x12\n\n\x02gt\x18\x04 \x01(\x12\x12\x0b\n\x03gte\x18\x05 \x01(\x12\x12\n\n\x02in\x18\x06 \x03(\x12\x12\x0e\n\x06not_in\x18\x07 \x03(\x12\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x81\x01\n\x0c\x46ixed32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x07\x12\n\n\x02lt\x18\x02 \x01(\x07\x12\x0b\n\x03lte\x18\x03 \x01(\x07\x12\n\n\x02gt\x18\x04 \x01(\x07\x12\x0b\n\x03gte\x18\x05 \x01(\x07\x12\n\n\x02in\x18\x06 \x03(\x07\x12\x0e\n\x06not_in\x18\x07 \x03(\x07\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x81\x01\n\x0c\x46ixed64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x06\x12\n\n\x02lt\x18\x02 \x01(\x06\x12\x0b\n\x03lte\x18\x03 \x01(\x06\x12\n\n\x02gt\x18\x04 \x01(\x06\x12\x0b\n\x03gte\x18\x05 \x01(\x06\x12\n\n\x02in\x18\x06 \x03(\x06\x12\x0e\n\x06not_in\x18\x07 \x03(\x06\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x82\x01\n\rSFixed32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x0f\x12\n\n\x02lt\x18\x02 \x01(\x0f\x12\x0b\n\x03lte\x18\x03 \x01(\x0f\x12\n\n\x02gt\x18\x04 \x01(\x0f\x12\x0b\n\x03gte\x18\x05 \x01(\x0f\x12\n\n\x02in\x18\x06 \x03(\x0f\x12\x0e\n\x06not_in\x18\x07 \x03(\x0f\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x82\x01\n\rSFixed64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x10\x12\n\n\x02lt\x18\x02 \x01(\x10\x12\x0b\n\x03lte\x18\x03 \x01(\x10\x12\n\n\x02gt\x18\x04 \x01(\x10\x12\x0b\n\x03gte\x18\x05 \x01(\x10\x12\n\n\x02in\x18\x06 \x03(\x10\x12\x0e\n\x06not_in\x18\x07 \x03(\x10\x12\x14\n\x0cignore_empty\x18\x08 \x01(\x08\"\x1a\n\tBoolRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x08\"\xfd\x03\n\x0bStringRules\x12\r\n\x05\x63onst\x18\x01 \x01(\t\x12\x0b\n\x03len\x18\x13 \x01(\x04\x12\x0f\n\x07min_len\x18\x02 \x01(\x04\x12\x0f\n\x07max_len\x18\x03 \x01(\x04\x12\x11\n\tlen_bytes\x18\x14 \x01(\x04\x12\x11\n\tmin_bytes\x18\x04 \x01(\x04\x12\x11\n\tmax_bytes\x18\x05 \x01(\x04\x12\x0f\n\x07pattern\x18\x06 \x01(\t\x12\x0e\n\x06prefix\x18\x07 \x01(\t\x12\x0e\n\x06suffix\x18\x08 \x01(\t\x12\x10\n\x08\x63ontains\x18\t \x01(\t\x12\x14\n\x0cnot_contains\x18\x17 \x01(\t\x12\n\n\x02in\x18\n \x03(\t\x12\x0e\n\x06not_in\x18\x0b \x03(\t\x12\x0f\n\x05\x65mail\x18\x0c \x01(\x08H\x00\x12\x12\n\x08hostname\x18\r \x01(\x08H\x00\x12\x0c\n\x02ip\x18\x0e \x01(\x08H\x00\x12\x0e\n\x04ipv4\x18\x0f \x01(\x08H\x00\x12\x0e\n\x04ipv6\x18\x10 \x01(\x08H\x00\x12\r\n\x03uri\x18\x11 \x01(\x08H\x00\x12\x11\n\x07uri_ref\x18\x12 \x01(\x08H\x00\x12\x11\n\x07\x61\x64\x64ress\x18\x15 \x01(\x08H\x00\x12\x0e\n\x04uuid\x18\x16 \x01(\x08H\x00\x12\x30\n\x10well_known_regex\x18\x18 \x01(\x0e\x32\x14.validate.KnownRegexH\x00\x12\x14\n\x06strict\x18\x19 \x01(\x08:\x04true\x12\x14\n\x0cignore_empty\x18\x1a \x01(\x08\x42\x0c\n\nwell_known\"\xfb\x01\n\nBytesRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x0c\x12\x0b\n\x03len\x18\r \x01(\x04\x12\x0f\n\x07min_len\x18\x02 \x01(\x04\x12\x0f\n\x07max_len\x18\x03 \x01(\x04\x12\x0f\n\x07pattern\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\x0c\x12\x0e\n\x06suffix\x18\x06 \x01(\x0c\x12\x10\n\x08\x63ontains\x18\x07 \x01(\x0c\x12\n\n\x02in\x18\x08 \x03(\x0c\x12\x0e\n\x06not_in\x18\t \x03(\x0c\x12\x0c\n\x02ip\x18\n \x01(\x08H\x00\x12\x0e\n\x04ipv4\x18\x0b \x01(\x08H\x00\x12\x0e\n\x04ipv6\x18\x0c \x01(\x08H\x00\x12\x14\n\x0cignore_empty\x18\x0e \x01(\x08\x42\x0c\n\nwell_known\"L\n\tEnumRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x05\x12\x14\n\x0c\x64\x65\x66ined_only\x18\x02 \x01(\x08\x12\n\n\x02in\x18\x03 \x03(\x05\x12\x0e\n\x06not_in\x18\x04 \x03(\x05\".\n\x0cMessageRules\x12\x0c\n\x04skip\x18\x01 \x01(\x08\x12\x10\n\x08required\x18\x02 \x01(\x08\"\x80\x01\n\rRepeatedRules\x12\x11\n\tmin_items\x18\x01 \x01(\x04\x12\x11\n\tmax_items\x18\x02 \x01(\x04\x12\x0e\n\x06unique\x18\x03 \x01(\x08\x12#\n\x05items\x18\x04 \x01(\x0b\x32\x14.validate.FieldRules\x12\x14\n\x0cignore_empty\x18\x05 \x01(\x08\"\xa3\x01\n\x08MapRules\x12\x11\n\tmin_pairs\x18\x01 \x01(\x04\x12\x11\n\tmax_pairs\x18\x02 \x01(\x04\x12\x11\n\tno_sparse\x18\x03 \x01(\x08\x12\"\n\x04keys\x18\x04 \x01(\x0b\x32\x14.validate.FieldRules\x12$\n\x06values\x18\x05 \x01(\x0b\x32\x14.validate.FieldRules\x12\x14\n\x0cignore_empty\x18\x06 \x01(\x08\"8\n\x08\x41nyRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\n\n\x02in\x18\x02 \x03(\t\x12\x0e\n\x06not_in\x18\x03 \x03(\t\"\xbb\x02\n\rDurationRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12(\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02lt\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03lte\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02gt\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03gte\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02in\x18\x07 \x03(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06not_in\x18\x08 \x03(\x0b\x32\x19.google.protobuf.Duration\"\xba\x02\n\x0eTimestampRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12)\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02lt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03lte\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02gt\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03gte\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06lt_now\x18\x07 \x01(\x08\x12\x0e\n\x06gt_now\x18\x08 \x01(\x08\x12)\n\x06within\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration*F\n\nKnownRegex\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10HTTP_HEADER_NAME\x10\x01\x12\x15\n\x11HTTP_HEADER_VALUE\x10\x02:2\n\x08\x64isabled\x12\x1f.google.protobuf.MessageOptions\x18\xaf\x08 \x01(\x08:1\n\x07ignored\x12\x1f.google.protobuf.MessageOptions\x18\xb0\x08 \x01(\x08:0\n\x08required\x12\x1d.google.protobuf.OneofOptions\x18\xaf\x08 \x01(\x08:C\n\x05rules\x12\x1d.google.protobuf.FieldOptions\x18\xaf\x08 \x01(\x0b\x32\x14.validate.FieldRulesBP\n\x1aio.envoyproxy.pgv.validateZ2github.com/envoyproxy/protoc-gen-validate/validate')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'validate.validate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.envoyproxy.pgv.validateZ2github.com/envoyproxy/protoc-gen-validate/validate'
  _globals['_KNOWNREGEX']._serialized_start=4541
  _globals['_KNOWNREGEX']._serialized_end=4611
  _globals['_FIELDRULES']._serialized_start=137
  _globals['_FIELDRULES']._serialized_end=1057
  _globals['_FLOATRULES']._serialized_start=1059
  _globals['_FLOATRULES']._serialized_end=1186
  _globals['_DOUBLERULES']._serialized_start=1189
  _globals['_DOUBLERULES']._serialized_end=1317
  _globals['_INT32RULES']._serialized_start=1319
  _globals['_INT32RULES']._serialized_end=1446
  _globals['_INT64RULES']._serialized_start=1448
  _globals['_INT64RULES']._serialized_end=1575
  _globals['_UINT32RULES']._serialized_start=1578
  _globals['_UINT32RULES']._serialized_end=1706
  _globals['_UINT64RULES']._serialized_start=1709
  _globals['_UINT64RULES']._serialized_end=1837
  _globals['_SINT32RULES']._serialized_start=1840
  _globals['_SINT32RULES']._serialized_end=1968
  _globals['_SINT64RULES']._serialized_start=1971
  _globals['_SINT64RULES']._serialized_end=2099
  _globals['_FIXED32RULES']._serialized_start=2102
  _globals['_FIXED32RULES']._serialized_end=2231
  _globals['_FIXED64RULES']._serialized_start=2234
  _globals['_FIXED64RULES']._serialized_end=2363
  _globals['_SFIXED32RULES']._serialized_start=2366
  _globals['_SFIXED32RULES']._serialized_end=2496
  _globals['_SFIXED64RULES']._serialized_start=2499
  _globals['_SFIXED64RULES']._serialized_end=2629
  _globals['_BOOLRULES']._serialized_start=2631
  _globals['_BOOLRULES']._serialized_end=2657
  _globals['_STRINGRULES']._serialized_start=2660
  _globals['_STRINGRULES']._serialized_end=3169
  _globals['_BYTESRULES']._serialized_start=3172
  _globals['_BYTESRULES']._serialized_end=3423
  _globals['_ENUMRULES']._serialized_start=3425
  _globals['_ENUMRULES']._serialized_end=3501
  _globals['_MESSAGERULES']._serialized_start=3503
  _globals['_MESSAGERULES']._serialized_end=3549
  _globals['_REPEATEDRULES']._serialized_start=3552
  _globals['_REPEATEDRULES']._serialized_end=3680
  _globals['_MAPRULES']._serialized_start=3683
  _globals['_MAPRULES']._serialized_end=3846
  _globals['_ANYRULES']._serialized_start=3848
  _globals['_ANYRULES']._serialized_end=3904
  _globals['_DURATIONRULES']._serialized_start=3907
  _globals['_DURATIONRULES']._serialized_end=4222
  _globals['_TIMESTAMPRULES']._serialized_start=4225
  _globals['_TIMESTAMPRULES']._serialized_end=4539
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/datadog.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/datadog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/trace/v3/datadog.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"J\n\x13\x44\x61tadogRemoteConfig\x12\x33\n\x10polling_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xdd\x01\n\rDatadogConfig\x12\"\n\x11\x63ollector_cluster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x0cservice_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\x12\x63ollector_hostname\x18\x03 \x01(\t\x12\x41\n\rremote_config\x18\x04 \x01(\x0b\x32*.envoy.config.trace.v3.DatadogRemoteConfig:*\x9a\xc5\x88\x1e%\n#envoy.config.trace.v2.DatadogConfigB\xb3\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0c\x44\x61tadogProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05*\x12(envoy.extensions.tracers.datadog.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.datadog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\014DatadogProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005*\022(envoy.extensions.tracers.datadog.v4alpha\272\200\310\321\006\002\020\002'
  _globals['_DATADOGCONFIG'].fields_by_name['collector_cluster']._loaded_options = None
  _globals['_DATADOGCONFIG'].fields_by_name['collector_cluster']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DATADOGCONFIG'].fields_by_name['service_name']._loaded_options = None
  _globals['_DATADOGCONFIG'].fields_by_name['service_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DATADOGCONFIG']._loaded_options = None
  _globals['_DATADOGCONFIG']._serialized_options = b'\232\305\210\036%\n#envoy.config.trace.v2.DatadogConfig'
  _globals['_DATADOGREMOTECONFIG']._serialized_start=217
  _globals['_DATADOGREMOTECONFIG']._serialized_end=291
  _globals['_DATADOGCONFIG']._serialized_start=294
  _globals['_DATADOGCONFIG']._serialized_end=515
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/decompressor/v3/decompressor.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/decompressor/v3/decompressor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/http/decompressor/v3/decompressor.proto\x12-envoy.extensions.filters.http.decompressor.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x92\x06\n\x0c\x44\x65\x63ompressor\x12R\n\x14\x64\x65\x63ompressor_library\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12t\n\x18request_direction_config\x18\x02 \x01(\x0b\x32R.envoy.extensions.filters.http.decompressor.v3.Decompressor.RequestDirectionConfig\x12v\n\x19response_direction_config\x18\x03 \x01(\x0b\x32S.envoy.extensions.filters.http.decompressor.v3.Decompressor.ResponseDirectionConfig\x1av\n\x15\x43ommonDirectionConfig\x12\x39\n\x07\x65nabled\x18\x01 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12\"\n\x1aignore_no_transform_header\x18\x02 \x01(\x08\x1a\xc1\x01\n\x16RequestDirectionConfig\x12h\n\rcommon_config\x18\x01 \x01(\x0b\x32Q.envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfig\x12=\n\x19\x61\x64vertise_accept_encoding\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x83\x01\n\x17ResponseDirectionConfig\x12h\n\rcommon_config\x18\x01 \x01(\x0b\x32Q.envoy.extensions.filters.http.decompressor.v3.Decompressor.CommonDirectionConfigB\xbf\x01\n;io.envoyproxy.envoy.extensions.filters.http.decompressor.v3B\x11\x44\x65\x63ompressorProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/decompressor/v3;decompressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.decompressor.v3.decompressor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.http.decompressor.v3B\021DecompressorProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/decompressor/v3;decompressorv3\272\200\310\321\006\002\020\002'
  _globals['_DECOMPRESSOR'].fields_by_name['decompressor_library']._loaded_options = None
  _globals['_DECOMPRESSOR'].fields_by_name['decompressor_library']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_DECOMPRESSOR']._serialized_start=275
  _globals['_DECOMPRESSOR']._serialized_end=1061
  _globals['_DECOMPRESSOR_COMMONDIRECTIONCONFIG']._serialized_start=613
  _globals['_DECOMPRESSOR_COMMONDIRECTIONCONFIG']._serialized_end=731
  _globals['_DECOMPRESSOR_REQUESTDIRECTIONCONFIG']._serialized_start=734
  _globals['_DECOMPRESSOR_REQUESTDIRECTIONCONFIG']._serialized_end=927
  _globals['_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG']._serialized_start=930
  _globals['_DECOMPRESSOR_RESPONSEDIRECTIONCONFIG']._serialized_end=1061
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from envoy.service.tap.v3 import tap_pb2 as envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in envoy/service/tap/v3/tap_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TapSinkServiceStub(object):
    """[#protodoc-title: Tap sink service]

    [#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call
    StreamTaps to deliver captured taps to the server
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamTaps = channel.stream_unary(
                '/envoy.service.tap.v3.TapSinkService/StreamTaps',
                request_serializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsResponse.FromString,
                _registered_method=True)


class TapSinkServiceServicer(object):
    """[#protodoc-title: Tap sink service]

    [#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call
    StreamTaps to deliver captured taps to the server
    """

    def StreamTaps(self, request_iterator, context):
        """Envoy will connect and send StreamTapsRequest messages forever. It does not expect any
        response to be sent as nothing would be done in the case of failure. The server should
        disconnect if it expects Envoy to reconnect.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TapSinkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamTaps': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamTaps,
                    request_deserializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsRequest.FromString,
                    response_serializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.tap.v3.TapSinkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('envoy.service.tap.v3.TapSinkService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TapSinkService(object):
    """[#protodoc-title: Tap sink service]

    [#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call
    StreamTaps to deliver captured taps to the server
    """

    @staticmethod
    def StreamTaps(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/envoy.service.tap.v3.TapSinkService/StreamTaps',
            envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsRequest.SerializeToString,
            envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/discovery/v3/ads.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/discovery/v3/ads.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/discovery/v3/ads.proto\x12\x1a\x65nvoy.service.discovery.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"6\n\x08\x41\x64sDummy:*\x9a\xc5\x88\x1e%\n#envoy.service.discovery.v2.AdsDummy2\xa6\x02\n\x1a\x41ggregatedDiscoveryService\x12~\n\x19StreamAggregatedResources\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x87\x01\n\x18\x44\x65ltaAggregatedResources\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x42\x8d\x01\n(io.envoyproxy.envoy.service.discovery.v3B\x08\x41\x64sProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v3;discoveryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v3.ads_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v3B\010AdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v3;discoveryv3\272\200\310\321\006\002\020\002'
  _globals['_ADSDUMMY']._loaded_options = None
  _globals['_ADSDUMMY']._serialized_options = b'\232\305\210\036%\n#envoy.service.discovery.v2.AdsDummy'
  _globals['_ADSDUMMY']._serialized_start=178
  _globals['_ADSDUMMY']._serialized_end=232
  _globals['_AGGREGATEDDISCOVERYSERVICE']._serialized_start=235
  _globals['_AGGREGATEDDISCOVERYSERVICE']._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/custom_response/v3/custom_response.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/custom_response/v3/custom_response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/custom_response/v3/custom_response.proto\x12\x30\x65nvoy.extensions.filters.http.custom_response.v3\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x1dudpa/annotations/status.proto\"O\n\x0e\x43ustomResponse\x12=\n\x17\x63ustom_response_matcher\x18\x01 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\xd2\x01\n>io.envoyproxy.envoy.extensions.filters.http.custom_response.v3B\x13\x43ustomResponseProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/custom_response/v3;custom_responsev3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.custom_response.v3.custom_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.custom_response.v3B\023CustomResponseProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/custom_response/v3;custom_responsev3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_CUSTOMRESPONSE']._serialized_start=223
  _globals['_CUSTOMRESPONSE']._serialized_end=302
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/date.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/date.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16google/type/date.proto\x12\x0bgoogle.type\"0\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\x42]\n\x0f\x63om.google.typeB\tDateProtoP\x01Z4google.golang.org/genproto/googleapis/type/date;date\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.date_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\tDateProtoP\001Z4google.golang.org/genproto/googleapis/type/date;date\370\001\001\242\002\003GTP'
  _globals['_DATE']._serialized_start=39
  _globals['_DATE']._serialized_end=87
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/cluster/outlier_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/cluster/outlier_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/api/v2/cluster/outlier_detection.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9e\x0b\n\x10OutlierDetection\x12\x35\n\x0f\x63onsecutive_5xx\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12\x62\x61se_ejection_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14max_ejection_percent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12H\n\x19\x65nforcing_consecutive_5xx\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x45\n\x16\x65nforcing_success_rate\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12@\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19success_rate_stdev_factor\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1b\x63onsecutive_gateway_failure\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12T\n%enforcing_consecutive_gateway_failure\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12*\n\"split_external_local_origin_errors\x18\x0c \x01(\x08\x12\x46\n consecutive_local_origin_failure\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Y\n*enforcing_consecutive_local_origin_failure\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12R\n#enforcing_local_origin_success_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x66\x61ilure_percentage_threshold\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x65nforcing_failure_percentage\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12X\n)enforcing_failure_percentage_local_origin\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x46\n failure_percentage_minimum_hosts\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n!failure_percentage_request_volume\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xd6\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x15OutlierDetectionProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x19\x45nvoy::Api::V2::ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cluster.outlier_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.api.v2.clusterB\025OutlierDetectionProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\252\002\026Envoy.Api.V2.ClusterNS\352\002\031Envoy::Api::V2::ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001'
  _globals['_OUTLIERDETECTION'].fields_by_name['interval']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_OUTLIERDETECTION'].fields_by_name['base_ejection_time']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['base_ejection_time']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_OUTLIERDETECTION'].fields_by_name['max_ejection_percent']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['max_ejection_percent']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_5xx']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_5xx']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_success_rate']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_gateway_failure']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_gateway_failure']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_local_origin_failure']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_local_origin_failure']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_local_origin_success_rate']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_local_origin_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['failure_percentage_threshold']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['failure_percentage_threshold']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage_local_origin']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage_local_origin']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION']._serialized_start=223
  _globals['_OUTLIERDETECTION']._serialized_end=1661
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xds/core/v3/resource_name.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'xds/core/v3/resource_name.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.core.v3 import context_params_pb2 as xds_dot_core_dot_v3_dot_context__params__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fxds/core/v3/resource_name.proto\x12\x0bxds.core.v3\x1a\x1fxds/annotations/v3/status.proto\x1a xds/core/v3/context_params.proto\x1a\x17validate/validate.proto\"z\n\x0cResourceName\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t\x12\x1e\n\rresource_type\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12+\n\x07\x63ontext\x18\x04 \x01(\x0b\x32\x1a.xds.core.v3.ContextParamsBY\n\x16\x63om.github.xds.core.v3B\x11ResourceNameProtoP\x01Z\"github.com/cncf/xds/go/xds/core/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.core.v3.resource_name_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.github.xds.core.v3B\021ResourceNameProtoP\001Z\"github.com/cncf/xds/go/xds/core/v3\322\306\244\341\006\002\010\001'
  _globals['_RESOURCENAME'].fields_by_name['resource_type']._loaded_options = None
  _globals['_RESOURCENAME'].fields_by_name['resource_type']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RESOURCENAME']._serialized_start=140
  _globals['_RESOURCENAME']._serialized_end=262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/lua/v3/lua.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/lua/v3/lua.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/extensions/filters/http/lua/v3/lua.proto\x12$envoy.extensions.filters.http.lua.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcf\x02\n\x03Lua\x12 \n\x0binline_code\x18\x01 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12P\n\x0csource_codes\x18\x02 \x03(\x0b\x32:.envoy.extensions.filters.http.lua.v3.Lua.SourceCodesEntry\x12=\n\x13\x64\x65\x66\x61ult_source_code\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x13\n\x0bstat_prefix\x18\x04 \x01(\t\x1aT\n\x10SourceCodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSource:\x02\x38\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.filter.http.lua.v2.Lua\"\x8d\x01\n\x0bLuaPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x17\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x37\n\x0bsource_code\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\x42\x9b\x01\n2io.envoyproxy.envoy.extensions.filters.http.lua.v3B\x08LuaProtoP\x01ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/lua/v3;luav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.lua.v3.lua_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n2io.envoyproxy.envoy.extensions.filters.http.lua.v3B\010LuaProtoP\001ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/lua/v3;luav3\272\200\310\321\006\002\020\002'
  _globals['_LUA_SOURCECODESENTRY']._loaded_options = None
  _globals['_LUA_SOURCECODESENTRY']._serialized_options = b'8\001'
  _globals['_LUA'].fields_by_name['inline_code']._loaded_options = None
  _globals['_LUA'].fields_by_name['inline_code']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_LUA']._loaded_options = None
  _globals['_LUA']._serialized_options = b'\232\305\210\036%\n#envoy.config.filter.http.lua.v2.Lua'
  _globals['_LUAPERROUTE'].oneofs_by_name['override']._loaded_options = None
  _globals['_LUAPERROUTE'].oneofs_by_name['override']._serialized_options = b'\370B\001'
  _globals['_LUAPERROUTE'].fields_by_name['disabled']._loaded_options = None
  _globals['_LUAPERROUTE'].fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_LUAPERROUTE'].fields_by_name['name']._loaded_options = None
  _globals['_LUAPERROUTE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_LUA']._serialized_start=250
  _globals['_LUA']._serialized_end=585
  _globals['_LUA_SOURCECODESENTRY']._serialized_start=457
  _globals['_LUA_SOURCECODESENTRY']._serialized_end=541
  _globals['_LUAPERROUTE']._serialized_start=588
  _globals['_LUAPERROUTE']._serialized_end=729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/network/local_ratelimit/v3/local_rate_limit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/network/local_ratelimit/v3/local_rate_limit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJenvoy/extensions/filters/network/local_ratelimit/v3/local_rate_limit.proto\x12\x33\x65nvoy.extensions.filters.network.local_ratelimit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8c\x02\n\x0eLocalRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12:\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x0fruntime_enabled\x18\x03 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12\x11\n\tshare_key\x18\x04 \x01(\t:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimitB\xd0\x01\nAio.envoyproxy.envoy.extensions.filters.network.local_ratelimit.v3B\x13LocalRateLimitProtoP\x01Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/local_ratelimit/v3;local_ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.local_ratelimit.v3.local_rate_limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.network.local_ratelimit.v3B\023LocalRateLimitProtoP\001Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/local_ratelimit/v3;local_ratelimitv3\272\200\310\321\006\002\020\002'
  _globals['_LOCALRATELIMIT'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_LOCALRATELIMIT'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_LOCALRATELIMIT'].fields_by_name['token_bucket']._loaded_options = None
  _globals['_LOCALRATELIMIT'].fields_by_name['token_bucket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LOCALRATELIMIT']._loaded_options = None
  _globals['_LOCALRATELIMIT']._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimit'
  _globals['_LOCALRATELIMIT']._serialized_start=290
  _globals['_LOCALRATELIMIT']._serialized_end=558
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/quaternion.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/quaternion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgoogle/type/quaternion.proto\x12\x0bgoogle.type\"8\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01w\x18\x04 \x01(\x01\x42o\n\x0f\x63om.google.typeB\x0fQuaternionProtoP\x01Z@google.golang.org/genproto/googleapis/type/quaternion;quaternion\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.quaternion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\017QuaternionProtoP\001Z@google.golang.org/genproto/googleapis/type/quaternion;quaternion\370\001\001\242\002\003GTP'
  _globals['_QUATERNION']._serialized_start=45
  _globals['_QUATERNION']._serialized_end=101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/v3/ratelimit_unit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/v3/ratelimit_unit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/type/v3/ratelimit_unit.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto*\\\n\rRateLimitUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SECOND\x10\x01\x12\n\n\x06MINUTE\x10\x02\x12\x08\n\x04HOUR\x10\x03\x12\x07\n\x03\x44\x41Y\x10\x04\x12\t\n\x05MONTH\x10\x05\x12\x08\n\x04YEAR\x10\x06\x42x\n\x1bio.envoyproxy.envoy.type.v3B\x12RatelimitUnitProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.v3.ratelimit_unit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033io.envoyproxy.envoy.type.v3B\022RatelimitUnitProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\272\200\310\321\006\002\020\002'
  _globals['_RATELIMITUNIT']._serialized_start=84
  _globals['_RATELIMITUNIT']._serialized_end=176
# @@protoc_insertion_point(module_scope)
